package com.luojigou.xiaodou.wifi

import android.annotation.SuppressLint
import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.net.wifi.WifiManager
import android.os.Build
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import androidx.core.content.ContextCompat
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.luojigou.xiaodou.R
import com.luojigou.xiaodou.XDScanBLEService

@SuppressLint("MissingPermission")
class XDScanWifiNormalFragment(private val host: XDScanWifiStatus.Host) : Fragment() {
    private lateinit var wifiScanReceiver: BroadcastReceiver

    private val adapter = XDScanWifiAdapter { wifi ->
        XDScanWifiPasswordFragment {
            val intent = Intent(XDScanBLEService.ACTION_SELECT_WIFI_DEVICE)
            intent.putExtra(
                XDScanBLEService.ACTION_SELECT_WIFI_DEVICE_DATA, XDScanWifiInfo(
                    ssid = if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.TIRAMISU) {
                        val s = wifi.wifiSsid.toString()
                        s.substring(1, s.length - 1)
                    } else {
                        wifi.BSSID
                    }, password = it
                )
            )
            requireActivity().sendBroadcast(intent)
        }.show(requireActivity().supportFragmentManager, "password")
    }

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?
    ): View {
        return inflater.inflate(R.layout.fragment_scanwifi_normal, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val restartScanButton = view.findViewById<Button>(R.id.scan_again) //        restartScanButton.setOnClickListener { restartScan() }

        val recyclerView = view.findViewById<RecyclerView>(R.id.scan_list)
        val layoutManager = LinearLayoutManager(requireContext(), RecyclerView.VERTICAL, false)
        recyclerView.layoutManager = layoutManager
        recyclerView.adapter = adapter
    }

    override fun onAttach(context: Context) {
        super.onAttach(context)

        wifiScanReceiver = object : BroadcastReceiver() {
            override fun onReceive(context: Context?, intent: Intent) {
                when (intent.action) {
                    WifiManager.SCAN_RESULTS_AVAILABLE_ACTION -> {
                        if (intent.getBooleanExtra(WifiManager.EXTRA_RESULTS_UPDATED, false)) {
                            val scanResults = host.getWifiManager().scanResults

                            scanResults.forEach {
                                adapter.addValue(it)
                            }
                        }
                    }
                }
            }
        }

        val intentFilter = IntentFilter().apply {
            addAction(WifiManager.SCAN_RESULTS_AVAILABLE_ACTION)
        }

        ContextCompat.registerReceiver(
            requireContext(), wifiScanReceiver, intentFilter, ContextCompat.RECEIVER_EXPORTED
        )

        host.getWifiManager().startScan()
    }

    override fun onDetach() {
        requireContext().unregisterReceiver(wifiScanReceiver)
        super.onDetach()
    }
}